==> holidays-0.14.2.tar.gz: holidays-0.14.2/holidays/countries/__init__.py <==
#  python-holidays
#  ---------------
#  A fast, efficient Python library for generating country, province and state
#  specific sets of holidays on the fly. It aims to make determining whether a
#  specific date is a holiday as fast and flexible as possible.
#
#  Authors: dr-prodigy <maurizio.montel@gmail.com> (c) 2017-2022
#           ryanss <ryanssdev@icloud.com> (c) 2014-2017
#  Website: https://github.com/dr-prodigy/python-holidays
#  License: MIT (see LICENSE file)

from .angola import Angola, AO, AGO
from .argentina import Argentina, AR, ARG
from .aruba import Aruba, AW, ABW
from .australia import Australia, AU, AUS
from .austria import Austria, AT, AUT
from .azerbaijan import Azerbaijan, AZ, AZE
from .bangladesh import Bangladesh, BD, BGD
from .belarus import Belarus, BY, BLR
from .belgium import Belgium, BE, BEL
from .botswana import Botswana, BW, BWA
from .brazil import Brazil, BR, BRA
from .bulgaria import Bulgaria, BG, BLG
from .burundi import Burundi, BI, BDI
from .canada import Canada, CA, CAN
from .chile import Chile, CL, CHL
from .china import China, CN, CHN
from .colombia import Colombia, CO, COL
from .croatia import Croatia, HR, HRV
from .curacao import Curacao, CW, CUW
from .cyprus import Cyprus, CY, CYP
from .czechia import Czechia, CZ, CZE
from .denmark import Denmark, DK, DNK
from .djibouti import Djibouti, DJ, DJI
from .dominican_republic import DominicanRepublic, DO, DOM
from .egypt import Egypt, EG, EGY
from .estonia import Estonia, EE, EST
from .ethiopia import Ethiopia, ET, ETH
from .finland import Finland, FI, FIN
from .france import France, FR, FRA
from .georgia import Georgia, GE, GEO
from .germany import Germany, DE, DEU
from .greece import Greece, GR, GRC
from .honduras import Honduras, HN, HND
from .hongkong import HongKong, HK, HKG
from .hungary import Hungary, HU, HUN
from .iceland import Iceland, IS, ISL
from .india import India, IN, IND
from .ireland import Ireland, IE, IRL
from .isle_of_man import IsleOfMan, IM
from .italy import Italy, IT, ITA
from .israel import Israel, IL, ISR
from .jamaica import Jamaica, JM, JAM
from .japan import Japan, JP, JPN
from .kazakhstan import Kazakhstan, KZ, KAZ
from .kenya import Kenya, KE, KEN
from .korea import Korea, KR, KOR
from .latvia import Latvia, LV, LVA
from .lesotho import Lesotho, LS, LSO
from .lithuania import Lithuania, LT, LTU
from .luxembourg import Luxembourg, LU, LUX
from .madagascar import Madagascar, MG, MDG
from .malawi import Malawi, MW, MWI
from .malaysia import Malaysia, MY, MYS
from .malta import Malta, MT, MLT
from .mexico import Mexico, MX, MEX
from .morocco import Morocco, MA, MOR
from .mozambique import Mozambique, MZ, MOZ
from .namibia import Namibia, NA, NAM
from .netherlands import Netherlands, NL, NLD
from .new_zealand import NewZealand, NZ, NZL
from .nicaragua import Nicaragua, NI, NIC
from .nigeria import Nigeria, NG, NGA
from .north_macedonia import NorthMacedonia, MK, MKD
from .norway import Norway, NO, NOR
from .paraguay import Paraguay, PY, PRY
from .peru import Peru, PE, PER
from .poland import Poland, PL, POL
from .portugal import Portugal, PT, PRT, PortugalExt, PTE, PRTE
from .romania import Romania, RO, ROU
from .russia import Russia, RU, RUS
from .saudi_arabia import SaudiArabia, SA, SAU
from .serbia import Serbia, RS, SRB
from .singapore import Singapore, SG, SGP
from .slovakia import Slovakia, SK, SVK
from .slovenia import Slovenia, SI, SVN
from .south_africa import SouthAfrica, ZA, ZAF
from .spain import Spain, ES, ESP
from .swaziland import Swaziland, SZ, SZW
from .sweden import Sweden, SE, SWE
from .switzerland import Switzerland, CH, CHE
from .taiwan import Taiwan, TW, TWN
from .turkey import Turkey, TR, TUR
from .tunisia import Tunisia, TUN, TN
from .ukraine import Ukraine, UA, UKR
from .united_arab_emirates import UnitedArabEmirates, AE, ARE
from .united_kingdom import (
    UnitedKingdom,
    UK,
    GB,
    GBR,
    England,
    Wales,
    Scotland,
    NorthernIreland,
)
from .united_states import UnitedStates, US, USA
from .uruguay import Uruguay, UY, URY
from .uzbekistan import Uzbekistan, UZ, UZB
from .venezuela import Venezuela, VE, VEN
from .vietnam import Vietnam, VN, VNM
from .zambia import Zambia, ZM, ZMB
from .zimbabwe import Zimbabwe, ZW, ZWE

==> holidays-0.22.tar.gz: holidays-0.22/holidays/countries/__init__.py <==
#  python-holidays
#  ---------------
#  A fast, efficient Python library for generating country, province and state
#  specific sets of holidays on the fly. It aims to make determining whether a
#  specific date is a holiday as fast and flexible as possible.
#
#  Authors: dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
#           ryanss <ryanssdev@icloud.com> (c) 2014-2017
#  Website: https://github.com/dr-prodigy/python-holidays
#  License: MIT (see LICENSE file)

from .albania import Albania, AL, ALB
from .american_samoa import AmericanSamoa, AS, ASM, HolidaysAS
from .andorra import Andorra, AD, AND
from .angola import Angola, AO, AGO
from .argentina import Argentina, AR, ARG
from .armenia import Armenia, AM, ARM
from .aruba import Aruba, AW, ABW
from .australia import Australia, AU, AUS
from .austria import Austria, AT, AUT
from .azerbaijan import Azerbaijan, AZ, AZE
from .bahrain import Bahrain, BH, BAH
from .bangladesh import Bangladesh, BD, BGD
from .belarus import Belarus, BY, BLR
from .belgium import Belgium, BE, BEL
from .bolivia import Bolivia, BO, BOL
from .bosnia_and_herzegovina import BosniaAndHerzegovina, BA, BIH
from .botswana import Botswana, BW, BWA
from .brazil import Brazil, BR, BRA
from .bulgaria import Bulgaria, BG, BLG
from .burundi import Burundi, BI, BDI
from .canada import Canada, CA, CAN
from .chile import Chile, CL, CHL
from .china import China, CN, CHN
from .colombia import Colombia, CO, COL
from .costa_rica import CostaRica, CR, CRI
from .croatia import Croatia, HR, HRV
from .cuba import Cuba, CU, CUB
from .curacao import Curacao, CW, CUW
from .cyprus import Cyprus, CY, CYP
from .czechia import Czechia, CZ, CZE
from .denmark import Denmark, DK, DNK
from .djibouti import Djibouti, DJ, DJI
from .dominican_republic import DominicanRepublic, DO, DOM
from .egypt import Egypt, EG, EGY
from .estonia import Estonia, EE, EST
from .eswatini import Eswatini, SZ, SZW, Swaziland
from .ethiopia import Ethiopia, ET, ETH
from .finland import Finland, FI, FIN
from .france import France, FR, FRA
from .georgia import Georgia, GE, GEO
from .germany import Germany, DE, DEU
from .greece import Greece, GR, GRC
from .guam import Guam, GU, GUM, HolidaysGU
from .honduras import Honduras, HN, HND
from .hongkong import HongKong, HK, HKG
from .hungary import Hungary, HU, HUN
from .iceland import Iceland, IS, ISL
from .india import India, IN, IND
from .indonesia import Indonesia, ID, IDN
from .ireland import Ireland, IE, IRL
from .isle_of_man import IsleOfMan, IM, IMN
from .israel import Israel, IL, ISR
from .italy import Italy, IT, ITA
from .jamaica import Jamaica, JM, JAM
from .japan import Japan, JP, JPN
from .kazakhstan import Kazakhstan, KZ, KAZ
from .kenya import Kenya, KE, KEN
from .kyrgyzstan import Kyrgyzstan, KG, KGZ
from .latvia import Latvia, LV, LVA
from .lesotho import Lesotho, LS, LSO
from .liechtenstein import Liechtenstein, LI, LIE
from .lithuania import Lithuania, LT, LTU
from .luxembourg import Luxembourg, LU, LUX
from .madagascar import Madagascar, MG, MDG
from .malawi import Malawi, MW, MWI
from .malaysia import Malaysia, MY, MYS
from .malta import Malta, MT, MLT
from .marshall_islands import MarshallIslands, MH, MHL, HolidaysMH
from .mexico import Mexico, MX, MEX
from .moldova import Moldova, MD, MDA
from .monaco import Monaco, MC, MCO
from .montenegro import Montenegro, ME, MNE
from .morocco import Morocco, MA, MOR
from .mozambique import Mozambique, MZ, MOZ
from .namibia import Namibia, NA, NAM
from .netherlands import Netherlands, NL, NLD
from .new_zealand import NewZealand, NZ, NZL
from .nicaragua import Nicaragua, NI, NIC
from .nigeria import Nigeria, NG, NGA
from .north_macedonia import NorthMacedonia, MK, MKD
from .northern_mariana_islands import (
    NorthernMarianaIslands,
    MP,
    MNP,
    HolidaysMP,
)
from .norway import Norway, NO, NOR
from .pakistan import Pakistan, PK, PAK
from .panama import Panama, PA, PAN
from .paraguay import Paraguay, PY, PRY
from .peru import Peru, PE, PER
from .philippines import Philippines, PH, PHL
from .poland import Poland, PL, POL
from .portugal import Portugal, PT, PRT
from .puerto_rico import PuertoRico, PR, PRI, HolidaysPR
from .romania import Romania, RO, ROU
from .russia import Russia, RU, RUS
from .san_marino import SanMarino, SM, SMR
from .saudi_arabia import SaudiArabia, SA, SAU
from .serbia import Serbia, RS, SRB
from .singapore import Singapore, SG, SGP
from .slovakia import Slovakia, SK, SVK
from .slovenia import Slovenia, SI, SVN
from .south_africa import SouthAfrica, ZA, ZAF
from .south_korea import SouthKorea, KR, KOR, Korea
from .spain import Spain, ES, ESP
from .sweden import Sweden, SE, SWE
from .switzerland import Switzerland, CH, CHE
from .taiwan import Taiwan, TW, TWN
from .thailand import Thailand, TH, THA
from .tunisia import Tunisia, TN, TUN
from .turkey import Turkey, TR, TUR
from .ukraine import Ukraine, UA, UKR
from .united_arab_emirates import UnitedArabEmirates, AE, ARE
from .united_kingdom import UnitedKingdom, GB, GBR, UK
from .united_states import UnitedStates, US, USA
from .united_states_minor_outlying_islands import (
    UnitedStatesMinorOutlyingIslands,
    UM,
    UMI,
    HolidaysUM,
)
from .united_states_virgin_islands import (
    UnitedStatesVirginIslands,
    VI,
    VIR,
    HolidaysVI,
)
from .uruguay import Uruguay, UY, URY
from .uzbekistan import Uzbekistan, UZ, UZB
from .vatican_city import VaticanCity, VA, VAT
from .venezuela import Venezuela, VE, VEN
from .vietnam import Vietnam, VN, VNM
from .zambia import Zambia, ZM, ZMB
from .zimbabwe import Zimbabwe, ZW, ZWE
